@@ -1,6 +1,6 @@
 /*
  * This file is part of the ESO Recipe Execution Tool
- * Copyright (C) 2001-2017 European Southern Observatory
+ * Copyright (C) 2001-2022 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,9 +44,9 @@
 #include "er_plugin.h"
 #include "er_fileutils.h"
 
-#define DEV_BLOCKSIZE   4096
+#define DEV_BLOCKSIZE 4096
 
-#define Xspace(x)  (x == ' ') || (x == '\t') || (x == '\n')
+#define Xspace(x) (x == ' ') || (x == '\t') || (x == '\n')
 
 
 /**
@@ -76,40 +76,41 @@
  */
 /**********************************************************************/
 
-char *er_fileutils_env_replace (const char *path)
+char *
+er_fileutils_env_replace(const char *path)
 
 {
-
     static char expanded_path[PATHSET_MAX + 1];
     char tpath[PATHSET_MAX + 1];
 
     wordexp_t pwordexp;
 
 
-    (void) strncpy (expanded_path, path, PATHSET_MAX);
+    (void)strncpy(expanded_path, path, PATHSET_MAX);
 
 
     /* Perform tilde and environment variable expansion */
 
-    if (wordexp (path, &pwordexp, WRDE_NOCMD | WRDE_UNDEF) != 0)
-    {
-        cpl_msg_warning (er_func, "Unable to expand path '%s'\n", path);
+    if (wordexp(path, &pwordexp, WRDE_NOCMD | WRDE_UNDEF) != 0) {
+        cpl_msg_warning(er_func, "Unable to expand path '%s'\n", path);
 
-        if (pwordexp.we_wordc > 0) wordfree (&pwordexp);
+        if (pwordexp.we_wordc > 0)
+            wordfree(&pwordexp);
         return expanded_path;
     }
 
 
-    if (!pwordexp.we_wordv[0] || strlen (pwordexp.we_wordv[0]) > PATHSET_MAX)
-    {
-        cpl_msg_warning (er_func, "Buffer overflow while expanding "
-                         "path '%s'\n", path);
-        wordfree (&pwordexp);
+    if (!pwordexp.we_wordv[0] || strlen(pwordexp.we_wordv[0]) > PATHSET_MAX) {
+        cpl_msg_warning(er_func,
+                        "Buffer overflow while expanding "
+                        "path '%s'\n",
+                        path);
+        wordfree(&pwordexp);
         return expanded_path;
     }
 
-    (void) strcpy (expanded_path, pwordexp.we_wordv[0]);
-    wordfree (&pwordexp);
+    (void)strcpy(expanded_path, pwordexp.we_wordv[0]);
+    wordfree(&pwordexp);
 
 
     /* Return a pointer to the amended (if at all) string */
@@ -144,90 +145,86 @@ char *er_fileutils_env_replace (const char *path)
  */
 /**********************************************************************/
 
-const char *er_fileutils_tilde_replace (const char * name)
+const char *
+er_fileutils_tilde_replace(const char *name)
 
 {
     static char str[PATHSET_MAX];
     char *marker, *cpp;
 
-    int  len, lname;
+    int len, lname;
 
 
-    if (name == NULL) return NULL;
+    if (name == NULL)
+        return NULL;
 
-    lname = (int) strlen(name);
+    lname = (int)strlen(name);
 
     /* Only do this, if we start with a tilde (~) */
 
-    if (*name != '~')
-    {
-        if (lname > (PATHSET_MAX-1))
-        {
+    if (*name != '~') {
+        if (lname > (PATHSET_MAX - 1)) {
             cpl_msg_error(er_func,
                           "Buffer overflow in filename '%s' - fatal error",
                           name);
-            exit (EXIT_FAILURE);
+            exit(EXIT_FAILURE);
         }
         return (name);
     }
 
-    else
-    {       /* get HOME env. var., if we start with a tilde */
-        cpp = getenv ("HOME");
-        if (cpp == NULL)
-        {
+    else { /* get HOME env. var., if we start with a tilde */
+        cpp = getenv("HOME");
+        if (cpp == NULL) {
             cpl_msg_error(er_func,
                           "Env. variable HOME not set, could not replace `~'");
-            exit (EXIT_FAILURE);
+            exit(EXIT_FAILURE);
         }
 
-        len = (int) strlen(cpp);
-        if (len > (PATHSET_MAX-1))
-        {
-            cpl_msg_error (er_func,
-                           "Buffer overflow in filename '%s' - fatal error",
-                           name);
-            exit (EXIT_FAILURE);
+        len = (int)strlen(cpp);
+        if (len > (PATHSET_MAX - 1)) {
+            cpl_msg_error(er_func,
+                          "Buffer overflow in filename '%s' - fatal error",
+                          name);
+            exit(EXIT_FAILURE);
         }
-        (void) strcpy (str,cpp);
+        (void)strcpy(str, cpp);
 
-        len += lname;               /* +1 for \0 */
-        if (len > PATHSET_MAX)          /* -1 for (name+1) below */
+        len += lname;          /* +1 for \0 */
+        if (len > PATHSET_MAX) /* -1 for (name+1) below */
         {
             cpl_msg_error(er_func,
                           "Buffer overflow in filename '%s' - fatal error",
                           name);
-            exit (EXIT_FAILURE);
+            exit(EXIT_FAILURE);
         }
 
-        (void) strcat (str, name + 1);
+        (void)strcat(str, name + 1);
     }
 
 
     /* Remove any multiple slashes */
 
 
-    marker = strstr (str, "//");
-    while (marker != NULL)
-    {
-        memmove (marker, marker + 1, strlen (marker));
-        marker = strstr (str, "//");
+    marker = strstr(str, "//");
+    while (marker != NULL) {
+        memmove(marker, marker + 1, strlen(marker));
+        marker = strstr(str, "//");
     }
 
 
     /* Remove any trailing slashes */
 
-    marker = str - 1 + (int) strlen(str);       /* last char of `str' */
-    if ((*marker) == '/') *marker = '\0';
+    marker = str - 1 + (int)strlen(str); /* last char of `str' */
+    if ((*marker) == '/')
+        *marker = '\0';
 
 #ifdef HAVE_WORDEXP
-    return (er_fileutils_env_replace (str));
+    return (er_fileutils_env_replace(str));
 #else
 
     return (str);
 #endif
-
-}                            
+}
 
 
 /**********************************************************************/
@@ -252,29 +249,29 @@ const char *er_fileutils_tilde_replace (const char * name)
  */
 /**********************************************************************/
 
-const char *er_fileutils_dot_replace (const char * name)
+const char *
+er_fileutils_dot_replace(const char *name)
 
 {
     static char str[PATHSET_MAX];
-    char  *cpp;
+    char *cpp;
 
-    int  len, lname;
+    int len, lname;
 
 
-    if (name == NULL) return NULL;
+    if (name == NULL)
+        return NULL;
 
-    lname = (int) strlen(name);
+    lname = (int)strlen(name);
 
     /* if we don't start with a dot (.) just pass the name on */
 
-    if (*name != '.')
-    {
-        if (lname > (PATHSET_MAX-1))
-        {
-            cpl_msg_error (er_func,
-                           "Buffer overflow in filename '%s' - fatal error",
-                           name);
-            exit (EXIT_FAILURE);
+    if (*name != '.') {
+        if (lname > (PATHSET_MAX - 1)) {
+            cpl_msg_error(er_func,
+                          "Buffer overflow in filename '%s' - fatal error",
+                          name);
+            exit(EXIT_FAILURE);
         }
 
         return (name);
@@ -285,43 +282,40 @@ const char *er_fileutils_dot_replace (const char * name)
 
     cpp = getcwd(str, PATHSET_MAX);
 
-    if (cpp == NULL)
-    {
+    if (cpp == NULL) {
         cpl_msg_error(er_func, "Buffer overflow in filename '%s' - fatal error",
                       name);
         exit(EXIT_FAILURE);
     }
 
-    len = (int) strlen(cpp);
+    len = (int)strlen(cpp);
 
 
     /* Handle the ".." case (add a "/." as the "." replacement) */
 
-    if (*(name + 1) == '.')
-    {
-        if ((len+2) > (PATHSET_MAX-1))
-        {
-            cpl_msg_error (er_func,
-                           "Buffer overflow in filename '%s' - fatal error",
-                           name);
-            exit (EXIT_FAILURE);
+    if (*(name + 1) == '.') {
+        if ((len + 2) > (PATHSET_MAX - 1)) {
+            cpl_msg_error(er_func,
+                          "Buffer overflow in filename '%s' - fatal error",
+                          name);
+            exit(EXIT_FAILURE);
         }
-        (void) strcat (str, "/.");
+        (void)strcat(str, "/.");
         len += 2;
     }
 
-    len += lname;                   /* +1 for \0 */
-    if (len > PATHSET_MAX)              /* -1 for (name+1) below */
+    len += lname;          /* +1 for \0 */
+    if (len > PATHSET_MAX) /* -1 for (name+1) below */
     {
-        cpl_msg_error (er_func, "Buffer overflow in filename '%s'", name);
-        cpl_msg_error (er_func, "Fatal error replacing current working "
-                       "directory symbol due to buffer overflow");
-        exit (EXIT_FAILURE);
+        cpl_msg_error(er_func, "Buffer overflow in filename '%s'", name);
+        cpl_msg_error(er_func, "Fatal error replacing current working "
+                               "directory symbol due to buffer overflow");
+        exit(EXIT_FAILURE);
     }
 
-    (void) strcat(str, name + 1);       /* Add the rest of the file name */
+    (void)strcat(str, name + 1); /* Add the rest of the file name */
     return (str);
-}                            
+}
 
 
 /**********************************************************************/
@@ -335,24 +329,23 @@ const char *er_fileutils_dot_replace (const char * name)
  */
 /**********************************************************************/
 
-int fileutils_directory_exists (const char * directory_name)
+int
+fileutils_directory_exists(const char *directory_name)
 
 {
     DIR *dp;
 
 
-    if (directory_name != NULL)
-    {               /* no need to save the pointer, here! */
-        dp = opendir (er_fileutils_tilde_replace (directory_name));
-        if (dp != NULL)
-        {
-            (void) closedir (dp);
-            return 1;           /* that's TRUE */
+    if (directory_name != NULL) { /* no need to save the pointer, here! */
+        dp = opendir(er_fileutils_tilde_replace(directory_name));
+        if (dp != NULL) {
+            (void)closedir(dp);
+            return 1; /* that's TRUE */
         }
     }
 
-    return 0;           /* that's FALSE */
-}       
+    return 0; /* that's FALSE */
+}
 
 
 /**********************************************************************/
@@ -366,7 +359,8 @@ int fileutils_directory_exists (const char * directory_name)
  */
 /**********************************************************************/
 
-int fileutils_file_exists (const char * file_name)
+int
+fileutils_file_exists(const char *file_name)
 
 {
     int file_descriptor;
@@ -374,20 +368,19 @@ int fileutils_file_exists (const char * file_name)
     const char *resname;
 
 
-    if (file_name != NULL)
-    {               /* no need to save the pointer, here! */
-        resname = er_fileutils_dot_replace (er_fileutils_tilde_replace (file_name));
+    if (file_name != NULL) { /* no need to save the pointer, here! */
+        resname =
+            er_fileutils_dot_replace(er_fileutils_tilde_replace(file_name));
 
-        file_descriptor = open (resname, O_RDONLY);
-        if (file_descriptor > -1)
-        {
-            (void) close (file_descriptor);
+        file_descriptor = open(resname, O_RDONLY);
+        if (file_descriptor > -1) {
+            (void)close(file_descriptor);
             return 1;
         }
     }
 
-    return 0;           /* that's FALSE */
-} 
+    return 0; /* that's FALSE */
+}
 
 
 /**********************************************************************/
@@ -403,7 +396,8 @@ int fileutils_file_exists (const char * file_name)
  */
 /**********************************************************************/
 
-char *fileutils_create_fqfname (char * dir_name, char * file_name)
+char *
+fileutils_create_fqfname(char *dir_name, char *file_name)
 
 {
     char *fqfn = NULL;
@@ -412,26 +406,29 @@ char *fileutils_create_fqfname (char * dir_name, char * file_name)
     int ldn = 0, lfn = 0, lextra = 2;
 
 
-    if (file_name == NULL) return NULL;
+    if (file_name == NULL)
+        return NULL;
 
-    if (dir_name != NULL)
-    {
-        ldn = (int) strlen (dir_name);
-        if (dir_name[ldn] == '/') lextra = 1;
+    if (dir_name != NULL) {
+        ldn = (int)strlen(dir_name);
+        if (dir_name[ldn] == '/')
+            lextra = 1;
     }
 
-    lfn = (int) strlen (file_name);
-    n = sizeof (char) * (ldn + lfn + lextra);
-    fqfn = (char *) cpl_malloc ((size_t) n);
-    if (fqfn == NULL) return NULL;
+    lfn = (int)strlen(file_name);
+    n = sizeof(char) * (ldn + lfn + lextra);
+    fqfn = (char *)cpl_malloc((size_t)n);
+    if (fqfn == NULL)
+        return NULL;
 
-    (void) strcpy (fqfn, dir_name);
-    if (lextra == 2) (void) strcat (fqfn, "/");
-    (void) strcat (fqfn, file_name);
+    (void)strcpy(fqfn, dir_name);
+    if (lextra == 2)
+        (void)strcat(fqfn, "/");
+    (void)strcat(fqfn, file_name);
 
     return fqfn;
 
-}                               /* End of fileutils_create_fqfname() */
+} /* End of fileutils_create_fqfname() */
 
 
 /**********************************************************************/
@@ -445,36 +442,38 @@ char *fileutils_create_fqfname (char * dir_name, char * file_name)
  */
 /**********************************************************************/
 
-char *fileutils_fqfname_filename (const char * path)
+char *
+fileutils_fqfname_filename(const char *path)
 
 {
-    char  *fname;
+    char *fname;
     const char *pc;
 
     int len, j;
 
 
-    if (path == NULL) return NULL;
+    if (path == NULL)
+        return NULL;
 
-    len = (int) strlen (path);
+    len = (int)strlen(path);
     j = len;
 
     pc = path + len;
 
-    while ((j >= 0) && (*pc != '/'))
-    {
+    while ((j >= 0) && (*pc != '/')) {
         pc--;
         j--;
     }
 
-    fname = (char *) cpl_calloc ((size_t) (len - j), (size_t) sizeof (char));
-    if (fname == NULL) return NULL;
+    fname = (char *)cpl_calloc((size_t)(len - j), (size_t)sizeof(char));
+    if (fname == NULL)
+        return NULL;
 
-    (void) strncpy (fname, &path[j + 1], (size_t) (len-j-1));
+    (void)strncpy(fname, &path[j + 1], (size_t)(len - j - 1));
 
     return fname;
 
-}                               /* End of fileutils_fqfname_filename() */
+} /* End of fileutils_fqfname_filename() */
 
 
 /**********************************************************************/
@@ -488,36 +487,37 @@ char *fileutils_fqfname_filename (const char * path)
  */
 /**********************************************************************/
 
-char *fileutils_fqfname_dirname (const char * path)
+char *
+fileutils_fqfname_dirname(const char *path)
 
 {
-    char  *dname;
+    char *dname;
     const char *pc;
 
     int len, j;
 
 
-    if (path == NULL) return NULL;
+    if (path == NULL)
+        return NULL;
 
-    len = (int) strlen (path);
+    len = (int)strlen(path);
     j = len;
 
     pc = path + len;
 
-    while ((j >= 0) && (*pc != '/'))
-    {
+    while ((j >= 0) && (*pc != '/')) {
         pc--;
         j--;
     }
 
-    dname = (char *) cpl_calloc ((size_t) (j+1), (size_t) sizeof (char));
-    if (dname == NULL) return NULL;
+    dname = (char *)cpl_calloc((size_t)(j + 1), (size_t)sizeof(char));
+    if (dname == NULL)
+        return NULL;
 
-    (void) strncpy (dname, path, (size_t) j);
+    (void)strncpy(dname, path, (size_t)j);
 
     return dname;
-
-} 
+}
 
 
 /*
@@ -542,7 +542,8 @@ char *fileutils_fqfname_dirname (const char * path)
  * returns.
  */
 
-int fileutils_copy (const char * srcpath, const char * dstpath)
+int
+fileutils_copy(const char *srcpath, const char *dstpath)
 
 {
     char *buf;
@@ -555,72 +556,64 @@ int fileutils_copy (const char * srcpath, const char * dstpath)
     struct stat sb, db;
 
 
-    if ((stat(srcpath,&sb) == 0) && (stat(dstpath,&db) == 0))
-    {
+    if ((stat(srcpath, &sb) == 0) && (stat(dstpath, &db) == 0)) {
         if (sb.st_ino == db.st_ino)
-            return 99;  /* if inodes are the same we are done already... */
+            return 99; /* if inodes are the same we are done already... */
     }
 
-    if ((src = open (srcpath, O_RDONLY)) == -1) return (-1);
+    if ((src = open(srcpath, O_RDONLY)) == -1)
+        return (-1);
 
-    if ((fstat (src, &sb) == -1) || (!S_ISREG (sb.st_mode)))
-    {
-        (void) close (src);
+    if ((fstat(src, &sb) == -1) || (!S_ISREG(sb.st_mode))) {
+        (void)close(src);
         return -2;
     }
 
-    if ((dst = open (dstpath, O_CREAT | O_WRONLY | O_TRUNC, sb.st_mode)) == -1)
-    {
-        (void) close (src);
+    if ((dst = open(dstpath, O_CREAT | O_WRONLY | O_TRUNC, sb.st_mode)) == -1) {
+        (void)close(src);
         return -3;
     }
 
-    if ((fstat (dst, &db) == -1) || (!S_ISREG (db.st_mode)))
-    {
-        (void) close (src);
-        (void) close (dst);
-        (void) unlink (dstpath);
+    if ((fstat(dst, &db) == -1) || (!S_ISREG(db.st_mode))) {
+        (void)close(src);
+        (void)close(dst);
+        (void)unlink(dstpath);
         return -4;
     }
 
 #ifdef HAVE_ST_BLKSIZE
     blksize = db.st_blksize;
 #else
-#   ifdef DEV_BSIZE
+#ifdef DEV_BSIZE
     blksize = DEV_BSIZE;
-#   endif
+#endif
 #endif
 
-    if ((buf = (char *) cpl_malloc ((size_t)blksize)) == NULL)
-    {
-        (void) close (src);
-        (void) close (dst);
-        (void) unlink (dstpath);
+    if ((buf = (char *)cpl_malloc((size_t)blksize)) == NULL) {
+        (void)close(src);
+        (void)close(dst);
+        (void)unlink(dstpath);
         return -5;
     }
 
-    while ((rbytes = (int) read (src, buf, (size_t)blksize)) > 0)
-    {
-        if ((wbytes = (int) write (dst, buf, (size_t)rbytes)) != rbytes)
-        {
+    while ((rbytes = (int)read(src, buf, (size_t)blksize)) > 0) {
+        if ((wbytes = (int)write(dst, buf, (size_t)rbytes)) != rbytes) {
             wbytes = -1;
             break;
         }
     }
 
-    (void) close (src);
-    (void) close (dst);
-    cpl_free (buf);
+    (void)close(src);
+    (void)close(dst);
+    cpl_free(buf);
 
 
-    if ((rbytes == -1) || (wbytes == -1))
-    {
-        (void) unlink (dstpath);
+    if ((rbytes == -1) || (wbytes == -1)) {
+        (void)unlink(dstpath);
         return -6;
     }
 
     return 0;
-
 }
 
 
@@ -642,19 +635,18 @@ int fileutils_copy (const char * srcpath, const char * dstpath)
  */
 
 
-
-int fileutils_move (const char *srcpath, const char *dstpath)
+int
+fileutils_move(const char *srcpath, const char *dstpath)
 
 {
-    int  ii;
+    int ii;
 
     struct stat sb;
 
 
-    if ((ii = fileutils_copy (srcpath, dstpath)) != 0)
-    {
-        if (ii == 99)       /* different path name, but same inode */
-            return 99;      /* => it's the same file - do nothing */
+    if ((ii = fileutils_copy(srcpath, dstpath)) != 0) {
+        if (ii == 99)  /* different path name, but same inode */
+            return 99; /* => it's the same file - do nothing */
         else
             return (-2);
     }
@@ -665,16 +657,14 @@ int fileutils_move (const char *srcpath, const char *dstpath)
      * writable revert to the original state, i.e. remove the file copy.
      */
 
-    if (stat (srcpath, &sb) == -1 || !(sb.st_mode & S_IWUSR))
-    {
-        (void) unlink (dstpath);
+    if (stat(srcpath, &sb) == -1 || !(sb.st_mode & S_IWUSR)) {
+        (void)unlink(dstpath);
         return -1;
     }
 
-    (void) unlink (srcpath);
+    (void)unlink(srcpath);
     return 0;
-
-} 
+}
 
 
 /*
@@ -706,53 +696,51 @@ int fileutils_move (const char *srcpath, const char *dstpath)
  *
  */
 
-int er_fileutils_link (const char *link_path, const char *file_path)
+int
+er_fileutils_link(const char *link_path, const char *file_path)
 
 {
     char linkname[FILEMAX + 1];
     const char *s;
 
-    int  len;
+    int len;
 
     struct stat lb;
 
 
     /* Check if the input file is readable */
 
-    if (access (file_path, R_OK))
-    {
-        cpl_msg_error (er_func, "Product file is unreadable: %s", file_path);
+    if (access(file_path, R_OK)) {
+        cpl_msg_error(er_func, "Product file is unreadable: %s", file_path);
         return EXIT_FAILURE;
     }
 
 
     /* pull out the file name */
 
-    s = strrchr (file_path, '/');           /* points to last '/' */
-    if (s == NULL)
-    {
+    s = strrchr(file_path, '/'); /* points to last '/' */
+    if (s == NULL) {
         s = file_path;
     }
-    else
-    {
+    else {
         ++s;
     }
-    len = (int) strlen(s);
-    len = (int) strlen(link_path) + len + 1;
-    if (len > FILEMAX)
-    {
-        cpl_msg_error (er_func, "Buffer overflow - fatal error");
+    len = (int)strlen(s);
+    len = (int)strlen(link_path) + len + 1;
+    if (len > FILEMAX) {
+        cpl_msg_error(er_func, "Buffer overflow - fatal error");
         return EXIT_FAILURE;
     }
-    (void) snprintf (linkname, (size_t)FILEMAX, "%s/%s", link_path, s);
+    (void)snprintf(linkname, (size_t)FILEMAX, "%s/%s", link_path, s);
 
 
     /* check if link already there... */
 
     /* if (fileutils_file_is_there (linkname) == 1)  */
-    if (fileutils_file_exists (linkname) == 1)
-    {
-        cpl_msg_warning (er_func, "the link %s already exists - will be overwritten!",linkname);
+    if (fileutils_file_exists(linkname) == 1) {
+        cpl_msg_warning(er_func,
+                        "the link %s already exists - will be overwritten!",
+                        linkname);
     }
 
 
@@ -766,54 +754,46 @@ int er_fileutils_link (const char *link_path, const char *file_path)
 
 #if defined HAVE_LSTAT && defined HAVE_SYMLINK
 
-    if (lstat (linkname, &lb))
-    {
-        if (errno != ENOENT)
-        {
-            cpl_msg_error (er_func, "Cannot get file status: %s", linkname);
+    if (lstat(linkname, &lb)) {
+        if (errno != ENOENT) {
+            cpl_msg_error(er_func, "Cannot get file status: %s", linkname);
             return EXIT_FAILURE;
         }
     }
-    else
-    {
-        if (S_ISLNK (lb.st_mode))
-            (void) unlink (linkname);
-        else
-        {
-            cpl_msg_error (er_func, "Not a symbolic link: %s", linkname);
+    else {
+        if (S_ISLNK(lb.st_mode))
+            (void)unlink(linkname);
+        else {
+            cpl_msg_error(er_func, "Not a symbolic link: %s", linkname);
             return EXIT_FAILURE;
         }
     }
 
-    if (symlink (file_path, linkname) != 0)
-    {
-        cpl_msg_error (er_func, "Cannot create symbolic link for %s", file_path);
+    if (symlink(file_path, linkname) != 0) {
+        cpl_msg_error(er_func, "Cannot create symbolic link for %s", file_path);
         return EXIT_FAILURE;
     }
 
 #else
 
-    if (stat (linkname, &lb))
-    {
-        if (errno != ENOENT)
-        {
-            cpl_msg_error (er_func, "Cannot get file status: %s", linkname);
+    if (stat(linkname, &lb)) {
+        if (errno != ENOENT) {
+            cpl_msg_error(er_func, "Cannot get file status: %s", linkname);
             return EXIT_FAILURE;
         }
     }
     else
-        (void) unlink (linkname);
+        (void)unlink(linkname);
 
-    if (fileutils_copy (file_path, linkname) < 0)
-    {
-        cpl_msg_error (er_func, "Cannot copy %s", file_path);
+    if (fileutils_copy(file_path, linkname) < 0) {
+        cpl_msg_error(er_func, "Cannot copy %s", file_path);
         return EXIT_FAILURE;
     }
 #endif
 
     return EXIT_SUCCESS;
 
-}                               /* End of er_fileutils_link() */
+} /* End of er_fileutils_link() */
 
 
 /*----------------------------------------------------------------------------*/
@@ -825,51 +805,46 @@ int er_fileutils_link (const char *link_path, const char *file_path)
  */
 /*----------------------------------------------------------------------------*/
 
-int er_fileutils_file_is_fits(const char *name)
+int
+er_fileutils_file_is_fits(const char *name)
 
 {
     FILE *fp;
 
-    char  *line, *keyw, *eqchar, *kval;
+    char *line, *keyw, *eqchar, *kval;
 
     int is_fits = 0;
-    int  i, j, n;
+    int i, j, n;
 
     int mysscanf();
 
 
-
-
-    if (!(fp = fopen (name, "r")))
-    {
-        cpl_msg_error (er_func, "Unable to open FITS file '%s'", name);
+    if (!(fp = fopen(name, "r"))) {
+        cpl_msg_error(er_func, "Unable to open FITS file '%s'", name);
         return (-2);
     }
 
-    line = (char *) cpl_calloc((size_t) 82, (size_t) 1);
-    keyw = (char *) cpl_calloc((size_t) 80, (size_t) 1);
-    eqchar = (char *) cpl_calloc((size_t) 80, (size_t) 1);
-    kval = (char *) cpl_calloc((size_t) 80, (size_t) 1);
+    line = (char *)cpl_calloc((size_t)82, (size_t)1);
+    keyw = (char *)cpl_calloc((size_t)80, (size_t)1);
+    eqchar = (char *)cpl_calloc((size_t)80, (size_t)1);
+    kval = (char *)cpl_calloc((size_t)80, (size_t)1);
 
 
     /* Loop over first few lines in the file */
 
-    for (i=0; i<10; i++)
-    {
+    for (i = 0; i < 10; i++) {
         line[0] = '\0';
-        if (fgets (line, 80, fp) == NULL)
-        {
-            cpl_msg_error (er_func, "Failed to read file '%s'", name);
+        if (fgets(line, 80, fp) == NULL) {
+            cpl_msg_error(er_func, "Failed to read file '%s'", name);
             goto close_file;
         }
 
         j = 0;
-        while (Xspace(line[j]))     /* omit leading space */
+        while (Xspace(line[j])) /* omit leading space */
         {
-            j ++;
-            if (line[j] == '\0')
-            {
-                cpl_msg_error (er_func, "%s not a FITS file!", name);
+            j++;
+            if (line[j] == '\0') {
+                cpl_msg_error(er_func, "%s not a FITS file!", name);
                 goto close_file;
             }
         }
@@ -880,28 +855,27 @@ int er_fileutils_file_is_fits(const char *name)
          * FITS file.
          */
 
-        n = mysscanf (&line[j], keyw, eqchar, kval);        /* split up line */
+        n = mysscanf(&line[j], keyw, eqchar, kval); /* split up line */
         /* printf("we get n = %d, keyw = %s, %s, %s\n",n,keyw,kval, eqchar); */
 
-        if ((n == 3) && (strcmp(keyw,"SIMPLE") == 0)
-                && (*eqchar == '=') && (*kval == 'T'))
-        {
+        if ((n == 3) && (strcmp(keyw, "SIMPLE") == 0) && (*eqchar == '=') &&
+            (*kval == 'T')) {
             is_fits = 1;
             goto close_file;
         }
     }
 
     /* first 10 lines indicate no FITS header ... */
-    cpl_msg_error (er_func, "%s not a FITS file!", name);
+    cpl_msg_error(er_func, "%s not a FITS file!", name);
 
 
-    close_file:
+close_file:
     cpl_free(line);
     cpl_free(keyw);
     cpl_free(eqchar);
     cpl_free(kval);
 
-    fclose (fp);
+    fclose(fp);
     return is_fits;
 }
 
