@@ -1,6 +1,6 @@
 /*
  * This file is part of the ESO Recipe Execution Tool
- * Copyright (C) 2017 European Southern Observatory
+ * Copyright (C) 2017-2022 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -50,99 +50,94 @@
 
 cpl_boolean cpl_parameterlist_append_must_produce_error = CPL_FALSE;
 
-cpl_error_code _cpl_parameterlist_append(cpl_parameterlist *self,
-                                         cpl_parameter *parameter)
+cpl_error_code
+_cpl_parameterlist_append(cpl_parameterlist *self, cpl_parameter *parameter)
 {
-    if (cpl_parameterlist_append_must_produce_error)
-    {
+    if (cpl_parameterlist_append_must_produce_error) {
         return cpl_error_set_message("cpl_parameterlist_append",
                                      CPL_ERROR_ILLEGAL_OUTPUT, "dummy error");
     }
-    else
-    {
+    else {
         return cpl_parameterlist_append(self, parameter);
     }
 }
 
 cpl_boolean cpl_recipeconfig_get_tags_must_produce_error = CPL_FALSE;
 
-char** _cpl_recipeconfig_get_tags(const cpl_recipeconfig* self)
+char **
+_cpl_recipeconfig_get_tags(const cpl_recipeconfig *self)
 {
-    if (cpl_recipeconfig_get_tags_must_produce_error)
-    {
+    if (cpl_recipeconfig_get_tags_must_produce_error) {
         cpl_error_set_message("cpl_recipeconfig_get_tags",
                               CPL_ERROR_ILLEGAL_OUTPUT, "dummy error");
         return NULL;
     }
-    else
-    {
+    else {
         return cpl_recipeconfig_get_tags(self);
     }
 }
 
 cpl_boolean cpl_recipeconfig_get_inputs_must_produce_error = CPL_FALSE;
 
-char** _cpl_recipeconfig_get_inputs(const cpl_recipeconfig* self,
-                                    const char* tag)
+char **
+_cpl_recipeconfig_get_inputs(const cpl_recipeconfig *self, const char *tag)
 {
-    if (cpl_recipeconfig_get_inputs_must_produce_error)
-    {
+    if (cpl_recipeconfig_get_inputs_must_produce_error) {
         cpl_error_set_message("cpl_recipeconfig_get_inputs",
                               CPL_ERROR_ILLEGAL_OUTPUT, "dummy error");
         return NULL;
     }
-    else
-    {
+    else {
         return cpl_recipeconfig_get_inputs(self, tag);
     }
 }
 
 cpl_boolean cpl_recipeconfig_get_outputs_must_produce_error = CPL_FALSE;
 
-char** _cpl_recipeconfig_get_outputs(const cpl_recipeconfig* self,
-                                     const char* tag)
+char **
+_cpl_recipeconfig_get_outputs(const cpl_recipeconfig *self, const char *tag)
 {
-    if (cpl_recipeconfig_get_outputs_must_produce_error)
-    {
+    if (cpl_recipeconfig_get_outputs_must_produce_error) {
         cpl_error_set_message("cpl_recipeconfig_get_outputs",
                               CPL_ERROR_ILLEGAL_OUTPUT, "dummy error");
         return NULL;
     }
-    else
-    {
+    else {
         return cpl_recipeconfig_get_outputs(self, tag);
     }
 }
 
 cpl_boolean cpl_recipeconfig_set_tag_must_produce_error = CPL_FALSE;
 
-int _cpl_recipeconfig_set_tag(cpl_recipeconfig* self, const char* tag,
-                             cpl_size min_count, cpl_size max_count)
+int
+_cpl_recipeconfig_set_tag(cpl_recipeconfig *self,
+                          const char *tag,
+                          cpl_size min_count,
+                          cpl_size max_count)
 {
-    if (cpl_recipeconfig_set_tag_must_produce_error)
-    {
+    if (cpl_recipeconfig_set_tag_must_produce_error) {
         return cpl_error_set_message("cpl_recipeconfig_set_tag",
                                      CPL_ERROR_ILLEGAL_OUTPUT, "dummy error");
     }
-    else
-    {
+    else {
         return cpl_recipeconfig_set_tag(self, tag, min_count, max_count);
     }
 }
 
 cpl_boolean cpl_recipeconfig_set_input_must_produce_error = CPL_FALSE;
 
-int _cpl_recipeconfig_set_input(cpl_recipeconfig* self, const char* tag,
-                                const char* input, cpl_size min_count,
-                                cpl_size max_count)
+int
+_cpl_recipeconfig_set_input(cpl_recipeconfig *self,
+                            const char *tag,
+                            const char *input,
+                            cpl_size min_count,
+                            cpl_size max_count)
 {
-    if (cpl_recipeconfig_set_input_must_produce_error)
-    {
+    if (cpl_recipeconfig_set_input_must_produce_error) {
         return cpl_error_set_message("cpl_recipeconfig_set_input",
                                      CPL_ERROR_ILLEGAL_OUTPUT, "dummy error");
     }
-    else
-    {
+    else {
         return cpl_recipeconfig_set_input(self, tag, input, min_count,
                                           max_count);
     }
@@ -150,28 +145,28 @@ int _cpl_recipeconfig_set_input(cpl_recipeconfig* self, const char* tag,
 
 cpl_boolean cpl_recipeconfig_set_output_must_produce_error = CPL_FALSE;
 
-int _cpl_recipeconfig_set_output(cpl_recipeconfig* self, const char* tag,
-                                 const char* output)
+int
+_cpl_recipeconfig_set_output(cpl_recipeconfig *self,
+                             const char *tag,
+                             const char *output)
 {
-    if (cpl_recipeconfig_set_output_must_produce_error)
-    {
+    if (cpl_recipeconfig_set_output_must_produce_error) {
         return cpl_error_set_message("cpl_recipeconfig_set_output",
                                      CPL_ERROR_ILLEGAL_OUTPUT, "dummy error");
     }
-    else
-    {
+    else {
         return cpl_recipeconfig_set_output(self, tag, output);
     }
 }
 
 /* Replace calls in the code we want to test with our overloaded functions. */
-#define cpl_parameterlist_append _cpl_parameterlist_append
-#define cpl_recipeconfig_get_tags _cpl_recipeconfig_get_tags
-#define cpl_recipeconfig_get_inputs _cpl_recipeconfig_get_inputs
+#define cpl_parameterlist_append     _cpl_parameterlist_append
+#define cpl_recipeconfig_get_tags    _cpl_recipeconfig_get_tags
+#define cpl_recipeconfig_get_inputs  _cpl_recipeconfig_get_inputs
 #define cpl_recipeconfig_get_outputs _cpl_recipeconfig_get_outputs
-#define cpl_recipeconfig_set_tag _cpl_recipeconfig_set_tag
-#define cpl_recipeconfig_set_input _cpl_recipeconfig_set_input
-#define cpl_recipeconfig_set_output _cpl_recipeconfig_set_output
+#define cpl_recipeconfig_set_tag     _cpl_recipeconfig_set_tag
+#define cpl_recipeconfig_set_input   _cpl_recipeconfig_set_input
+#define cpl_recipeconfig_set_output  _cpl_recipeconfig_set_output
 #include "er_python.c"
 #undef cpl_parameterlist_append
 #undef cpl_recipeconfig_get_tags
@@ -191,7 +186,8 @@ static void test_plugin_initialize(void);
                                   Main
  -----------------------------------------------------------------------------*/
 
-int main(void)
+int
+main(void)
 {
     cpl_test_init(PACKAGE_BUGREPORT, CPL_MSG_WARNING);
 
@@ -206,51 +202,52 @@ int main(void)
                              Private functions
  -----------------------------------------------------------------------------*/
 
-static void test_plugin_initialize(void)
+static void
+test_plugin_initialize(void)
 {
-    char * module_name = NULL;
-    cpl_recipe2 * recipe = NULL;
-    cpl_recipe2 * recipe2 = NULL;
-    cpl_pluginlist * pluginlist = NULL;
-    cpl_parameter * param = NULL;
+    char *module_name = NULL;
+    cpl_recipe2 *recipe = NULL;
+    cpl_recipe2 *recipe2 = NULL;
+    cpl_pluginlist *pluginlist = NULL;
+    cpl_parameter *param = NULL;
 
     /* Loading a simulated plugin with one parameter and a simple recipe config
        structure. */
-    recipe = (cpl_recipe2 *) cpl_calloc(1, sizeof(cpl_recipe2));
+    recipe = (cpl_recipe2 *)cpl_calloc(1, sizeof(cpl_recipe2));
     cpl_test_assert(cpl_plugin_init(&recipe->base.interface, CPL_PLUGIN_API, 1,
                                     CPL_PLUGIN_TYPE_RECIPE_V2, "test_recipe",
                                     "simple test recipe", "description ...",
                                     "some author", "author@eso.org",
-                                    "copyright ...", NULL, NULL, NULL)
-                    == CPL_ERROR_NONE);
+                                    "copyright ...", NULL, NULL,
+                                    NULL) == CPL_ERROR_NONE);
 
     recipe->base.parameters = cpl_parameterlist_new();
     cpl_test_assert(recipe->base.parameters != NULL);
     param = cpl_parameter_new_value("test.par1", CPL_TYPE_INT, "int param",
                                     "test", 5);
     cpl_test_assert(param != NULL);
-    cpl_test_assert(cpl_parameterlist_append(recipe->base.parameters, param)
-                    == CPL_ERROR_NONE);
+    cpl_test_assert(cpl_parameterlist_append(recipe->base.parameters, param) ==
+                    CPL_ERROR_NONE);
     param = cpl_parameter_new_value("__class__", CPL_TYPE_STRING,
                                     "Python class name", "__python__",
                                     "recipeclass");
     cpl_test_assert(param != NULL);
-    cpl_test_assert(cpl_parameterlist_append(recipe->base.parameters, param)
-                    == CPL_ERROR_NONE);
+    cpl_test_assert(cpl_parameterlist_append(recipe->base.parameters, param) ==
+                    CPL_ERROR_NONE);
 
     recipe->config = cpl_recipeconfig_new();
     cpl_test_assert(recipe->config != NULL);
     cpl_test_assert(cpl_recipeconfig_set_tag(recipe->config, "RAW", 1, 1) == 0);
-    cpl_test_assert(cpl_recipeconfig_set_input(recipe->config, "RAW",
-                                               "CALIB", 1, 1)
-                    == 0);
-    cpl_test_assert(cpl_recipeconfig_set_output(recipe->config, "RAW", "PROD")
-                    == 0);
+    cpl_test_assert(
+        cpl_recipeconfig_set_input(recipe->config, "RAW", "CALIB", 1, 1) == 0);
+    cpl_test_assert(
+        cpl_recipeconfig_set_output(recipe->config, "RAW", "PROD") == 0);
 
     pluginlist = cpl_pluginlist_new();
     cpl_test_assert(pluginlist != NULL);
-    cpl_test_assert(cpl_pluginlist_append(pluginlist, &recipe->base.interface)
-                    == CPL_ERROR_NONE);
+    cpl_test_assert(
+        cpl_pluginlist_append(pluginlist, &recipe->base.interface) ==
+        CPL_ERROR_NONE);
 
     module_list = cx_map_new(string_key_compare, cpl_free,
                              (cx_free_func)er_json_pluginlist_delete);
@@ -264,10 +261,9 @@ static void test_plugin_initialize(void)
 
     /* Test error handling of plugin_initialize if cpl_parameterlist_append
        produces and error. */
-    recipe2 = (cpl_recipe2 *) cpl_calloc(1, sizeof(cpl_recipe2));
+    recipe2 = (cpl_recipe2 *)cpl_calloc(1, sizeof(cpl_recipe2));
     cpl_test_assert(cpl_plugin_copy(&recipe2->base.interface,
-                                    &recipe->base.interface)
-                    == CPL_ERROR_NONE);
+                                    &recipe->base.interface) == CPL_ERROR_NONE);
     cpl_parameterlist_append_must_produce_error = CPL_TRUE;
     cpl_recipeconfig_get_tags_must_produce_error = CPL_FALSE;
     cpl_recipeconfig_get_inputs_must_produce_error = CPL_FALSE;
@@ -284,10 +280,9 @@ static void test_plugin_initialize(void)
 
     /* Test error handling of plugin_initialize if cpl_recipeconfig_get_tags
        produces and error. */
-    recipe2 = (cpl_recipe2 *) cpl_calloc(1, sizeof(cpl_recipe2));
+    recipe2 = (cpl_recipe2 *)cpl_calloc(1, sizeof(cpl_recipe2));
     cpl_test_assert(cpl_plugin_copy(&recipe2->base.interface,
-                                    &recipe->base.interface)
-                    == CPL_ERROR_NONE);
+                                    &recipe->base.interface) == CPL_ERROR_NONE);
     cpl_parameterlist_append_must_produce_error = CPL_FALSE;
     cpl_recipeconfig_get_tags_must_produce_error = CPL_TRUE;
     cpl_recipeconfig_get_inputs_must_produce_error = CPL_FALSE;
@@ -304,10 +299,9 @@ static void test_plugin_initialize(void)
 
     /* Test error handling of plugin_initialize if cpl_recipeconfig_get_inputs
        produces and error. */
-    recipe2 = (cpl_recipe2 *) cpl_calloc(1, sizeof(cpl_recipe2));
+    recipe2 = (cpl_recipe2 *)cpl_calloc(1, sizeof(cpl_recipe2));
     cpl_test_assert(cpl_plugin_copy(&recipe2->base.interface,
-                                    &recipe->base.interface)
-                    == CPL_ERROR_NONE);
+                                    &recipe->base.interface) == CPL_ERROR_NONE);
     cpl_parameterlist_append_must_produce_error = CPL_FALSE;
     cpl_recipeconfig_get_tags_must_produce_error = CPL_FALSE;
     cpl_recipeconfig_get_inputs_must_produce_error = CPL_TRUE;
@@ -324,10 +318,9 @@ static void test_plugin_initialize(void)
 
     /* Test error handling of plugin_initialize if cpl_recipeconfig_get_outputs
        produces and error. */
-    recipe2 = (cpl_recipe2 *) cpl_calloc(1, sizeof(cpl_recipe2));
+    recipe2 = (cpl_recipe2 *)cpl_calloc(1, sizeof(cpl_recipe2));
     cpl_test_assert(cpl_plugin_copy(&recipe2->base.interface,
-                                    &recipe->base.interface)
-                    == CPL_ERROR_NONE);
+                                    &recipe->base.interface) == CPL_ERROR_NONE);
     cpl_parameterlist_append_must_produce_error = CPL_FALSE;
     cpl_recipeconfig_get_tags_must_produce_error = CPL_FALSE;
     cpl_recipeconfig_get_inputs_must_produce_error = CPL_FALSE;
@@ -344,10 +337,9 @@ static void test_plugin_initialize(void)
 
     /* Test error handling of plugin_initialize if cpl_recipeconfig_set_tag
        produces and error. */
-    recipe2 = (cpl_recipe2 *) cpl_calloc(1, sizeof(cpl_recipe2));
+    recipe2 = (cpl_recipe2 *)cpl_calloc(1, sizeof(cpl_recipe2));
     cpl_test_assert(cpl_plugin_copy(&recipe2->base.interface,
-                                    &recipe->base.interface)
-                    == CPL_ERROR_NONE);
+                                    &recipe->base.interface) == CPL_ERROR_NONE);
     cpl_parameterlist_append_must_produce_error = CPL_FALSE;
     cpl_recipeconfig_get_tags_must_produce_error = CPL_FALSE;
     cpl_recipeconfig_get_inputs_must_produce_error = CPL_FALSE;
@@ -364,10 +356,9 @@ static void test_plugin_initialize(void)
 
     /* Test error handling of plugin_initialize if cpl_recipeconfig_set_input
        produces and error. */
-    recipe2 = (cpl_recipe2 *) cpl_calloc(1, sizeof(cpl_recipe2));
+    recipe2 = (cpl_recipe2 *)cpl_calloc(1, sizeof(cpl_recipe2));
     cpl_test_assert(cpl_plugin_copy(&recipe2->base.interface,
-                                    &recipe->base.interface)
-                    == CPL_ERROR_NONE);
+                                    &recipe->base.interface) == CPL_ERROR_NONE);
     cpl_parameterlist_append_must_produce_error = CPL_FALSE;
     cpl_recipeconfig_get_tags_must_produce_error = CPL_FALSE;
     cpl_recipeconfig_get_inputs_must_produce_error = CPL_FALSE;
@@ -384,10 +375,9 @@ static void test_plugin_initialize(void)
 
     /* Test error handling of plugin_initialize if cpl_recipeconfig_set_output
        produces and error. */
-    recipe2 = (cpl_recipe2 *) cpl_calloc(1, sizeof(cpl_recipe2));
+    recipe2 = (cpl_recipe2 *)cpl_calloc(1, sizeof(cpl_recipe2));
     cpl_test_assert(cpl_plugin_copy(&recipe2->base.interface,
-                                    &recipe->base.interface)
-                    == CPL_ERROR_NONE);
+                                    &recipe->base.interface) == CPL_ERROR_NONE);
     cpl_parameterlist_append_must_produce_error = CPL_FALSE;
     cpl_recipeconfig_get_tags_must_produce_error = CPL_FALSE;
     cpl_recipeconfig_get_inputs_must_produce_error = CPL_FALSE;
@@ -412,10 +402,11 @@ static void test_plugin_initialize(void)
 
 #else /* ENABLE_PYTHON_RECIPES */
 
-int main(void)
+int
+main(void)
 {
     /* Indicate to the automake test runner that the tests are skipped. */
     return 77;
 }
 
-#endif  /* ENABLE_PYTHON_RECIPES */
+#endif /* ENABLE_PYTHON_RECIPES */
